import { Hono } from "hono";
import { accepts } from "hono/accepts";
import { cors } from "hono/cors";
import { errors } from "./utils/constants.js";
import { createHtmlResponse } from "./utils/createHtmlResponse.js";
import { createJsonResponse } from "./utils/createJsonResponse.js";
import { createStreamResponse } from "./utils/createStreamResponse.js";
import { createXmlResponse } from "./utils/createXmlResponse.js";
import { createZipFileResponse } from "./utils/createZipFileResponse.js";
import { getRequestData } from "./utils/getRequestData.js";
import { logger } from "hono/logger";
async function createVoidServer() {
  const app = new Hono();
  if (!process.env.CI) {
    app.use(logger());
  }
  app.use(cors());
  app.all("/:status{[4-5][0-9][0-9]}", async (c) => {
    const { status: originalStatusCode } = c.req.param();
    const status = Number.parseInt(originalStatusCode ?? "0", 10);
    c.status(status);
    return c.text(errors?.[status] ?? "Unknown Error");
  });
  app.all("/:status{204}", async (c) => {
    return c.body(null, 204);
  });
  app.all("/:filename{.+\\.(html|xml|json|zip)$}", async (c) => {
    const requestData = await getRequestData(c);
    const { filename } = c.req.param();
    if (filename?.endsWith(".html")) {
      return createHtmlResponse(c, requestData);
    }
    if (filename?.endsWith(".xml")) {
      return createXmlResponse(c, requestData);
    }
    if (filename?.endsWith(".zip")) {
      return createZipFileResponse(c);
    }
    return createJsonResponse(c, requestData);
  });
  app.get("/stream", async (c) => {
    return createStreamResponse(c);
  });
  app.all("/*", async (c) => {
    const requestData = await getRequestData(c);
    const acceptedContentType = accepts(c, {
      header: "Accept",
      supports: ["text/html", "application/xml", "application/zip"],
      default: "application/json"
    });
    if (acceptedContentType === "text/html") {
      return createHtmlResponse(c, requestData);
    }
    if (acceptedContentType === "application/xml") {
      return createXmlResponse(c, requestData);
    }
    if (acceptedContentType === "application/zip") {
      return createZipFileResponse(c);
    }
    return createJsonResponse(c, requestData);
  });
  return app;
}
export {
  createVoidServer
};
//# sourceMappingURL=createVoidServer.js.map
